@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin;
 use strict;
 use warnings;
 
-our $VERSION = '1.028';
+our $VERSION = '1.029';
 
 use CPANPLUS::Dist::Slackware::Util qw(catdir catfile slurp spurt run);
 
@@ -187,7 +187,7 @@ CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin - Add an init script and d
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin version 1.028.
+This document describes CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin version 1.029.
 
 =head1 SYNOPSIS
 
@@ -229,7 +229,7 @@ Requires the command C<cp>.
 
 SpamAssassin packages created with CPANPLUS::Dist::Slackware conflict with
 packages created with the SpamAssassin build script available at
-L<http://slackbuilds.org/>.
+L<https://slackbuilds.org/>.
 
 =head1 SEE ALSO
 
@@ -242,7 +242,7 @@ Andreas Voegele E<lt>voegelas@cpan.orgE<gt>
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs to C<bug-cpanplus-dist-slackware at rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org/>.
+through the web interface at L<https://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -251,6 +251,6 @@ Copyright 2012-2020 Andreas Voegele
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-See http://dev.perl.org/licenses/ for more information.
+See https://dev.perl.org/licenses/ for more information.
 
 =cut
